[Cmake-commits] CMake branch, master, updated. v2.8.11.2-668-gf0f7ee0

2013-07-31 Thread Kitware Robot
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, master has been updated
   via  f0f7ee0adf0887cdb0460ef6afda7615c36fcdbf (commit)
  from  0cecc7b485774be084a6d5a72e743ed9893daa5d (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=f0f7ee0adf0887cdb0460ef6afda7615c36fcdbf
commit f0f7ee0adf0887cdb0460ef6afda7615c36fcdbf
Author: Kitware Robot 
AuthorDate: Thu Aug 1 00:01:09 2013 -0400
Commit: Kitware Robot 
CommitDate: Thu Aug 1 00:01:09 2013 -0400

CMake Nightly Date Stamp

diff --git a/Source/CMakeVersion.cmake b/Source/CMakeVersion.cmake
index f63178e..0d165d2 100644
--- a/Source/CMakeVersion.cmake
+++ b/Source/CMakeVersion.cmake
@@ -2,5 +2,5 @@
 set(CMake_VERSION_MAJOR 2)
 set(CMake_VERSION_MINOR 8)
 set(CMake_VERSION_PATCH 11)
-set(CMake_VERSION_TWEAK 20130731)
+set(CMake_VERSION_TWEAK 20130801)
 #set(CMake_VERSION_RC 1)

---

Summary of changes:
 Source/CMakeVersion.cmake |2 +-
 1 files changed, 1 insertions(+), 1 deletions(-)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/cgi-bin/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, next, updated. v2.8.11.2-3551-g1bf070e

2013-07-31 Thread Stephen Kelly
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, next has been updated
   via  1bf070ea14b1dfab4d70b1debbd9e5d6b9c2fcb9 (commit)
   via  80e652f5cc279715ff57e1c64c6e5c460b201db4 (commit)
   via  43558156d451b605bb9a3d14d53a3896ea98d73a (commit)
  from  14668d1346619005d94b3c1777acb85abb0a4a57 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=1bf070ea14b1dfab4d70b1debbd9e5d6b9c2fcb9
commit 1bf070ea14b1dfab4d70b1debbd9e5d6b9c2fcb9
Merge: 14668d1 80e652f
Author: Stephen Kelly 
AuthorDate: Wed Jul 31 18:41:06 2013 -0400
Commit: CMake Topic Stage 
CommitDate: Wed Jul 31 18:41:06 2013 -0400

Merge topic 'INCLUDES-DESTINATION-no-config' into next

80e652f Export: Process generator expressions from INCLUDES DESTINATION.
4355815 cmTarget: Add NAME property


http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=80e652f5cc279715ff57e1c64c6e5c460b201db4
commit 80e652f5cc279715ff57e1c64c6e5c460b201db4
Author: Stephen Kelly 
AuthorDate: Wed Jul 31 16:40:35 2013 +0200
Commit: Stephen Kelly 
CommitDate: Thu Aug 1 00:37:25 2013 +0200

Export: Process generator expressions from INCLUDES DESTINATION.

Configuration sensitive expressions are not permitted.

diff --git a/Source/cmExportFileGenerator.cxx b/Source/cmExportFileGenerator.cxx
index 5b351bc..ef336ea 100644
--- a/Source/cmExportFileGenerator.cxx
+++ b/Source/cmExportFileGenerator.cxx
@@ -287,11 +287,33 @@ void 
cmExportFileGenerator::PopulateIncludeDirectoriesInterface(
 
   const char *propName = "INTERFACE_INCLUDE_DIRECTORIES";
   const char *input = target->GetProperty(propName);
-  if (!input && tei->InterfaceIncludeDirectories.empty())
+
+  cmListFileBacktrace lfbt;
+  cmGeneratorExpression ge(lfbt);
+
+  std::string dirs = tei->InterfaceIncludeDirectories;
+  this->ReplaceInstallPrefix(dirs);
+  cmsys::auto_ptr cge = ge.Parse(dirs);
+  std::string exportDirs = cge->Evaluate(target->GetMakefile(), 0,
+ false, target);
+
+  if (cge->GetHadContextSensitiveCondition())
+{
+cmMakefile* mf = target->GetMakefile();
+cmOStringStream e;
+e << "Target \"" << target->GetName() << "\" is installed with "
+"INCLUDES DESTINATION set to a context sensitive path.  Paths which "
+"depend on the configuration, policy values or the link interface are "
+"not supported.  Consider using target_include_directories instead.";
+mf->IssueMessage(cmake::FATAL_ERROR, e.str());
+return;
+}
+
+  if (!input && exportDirs.empty())
 {
 return;
 }
-  if ((input && !*input) && tei->InterfaceIncludeDirectories.empty())
+  if ((input && !*input) && exportDirs.empty())
 {
 // Set to empty
 properties[propName] = "";
@@ -300,7 +322,7 @@ void 
cmExportFileGenerator::PopulateIncludeDirectoriesInterface(
 
   std::string includes = (input?input:"");
   const char* sep = input ? ";" : "";
-  includes += sep + tei->InterfaceIncludeDirectories;
+  includes += sep + exportDirs;
   std::string prepro = cmGeneratorExpression::Preprocess(includes,
  preprocessRule,
  true);
diff --git a/Tests/ExportImport/Export/CMakeLists.txt 
b/Tests/ExportImport/Export/CMakeLists.txt
index 1910f8c..b5b2027 100644
--- a/Tests/ExportImport/Export/CMakeLists.txt
+++ b/Tests/ExportImport/Export/CMakeLists.txt
@@ -99,7 +99,6 @@ macro(add_include_lib _libName)
   set_property(TARGET ${_libName} APPEND PROPERTY
   INTERFACE_INCLUDE_DIRECTORIES
 "$"
-"$/include/${_libName}>"
   )
   if (NOT "${ARGV1}" STREQUAL "NO_HEADER")
   file(WRITE "${CMAKE_CURRENT_BINARY_DIR}/${_libName}/${_libName}.h" "// 
no content\n")
@@ -188,8 +187,7 @@ install(FILES
 DESTINATION include/testSharedLibRequired
 )
 set_property(TARGET testSharedLibRequired APPEND PROPERTY
-  INTERFACE_INCLUDE_DIRECTORIES 
"$/include/testSharedLibRequired>"
-
"$"
+  INTERFACE_INCLUDE_DIRECTORIES 
"$"
 )
 set_property(TARGET testSharedLibRequired APPEND PROPERTY
   INTERFACE_COMPILE_DEFINITIONS USING_TESTSHAREDLIBREQUIRED
@@ -273,18 +271,24 @@ set_property(TARGET cmp0022OLD APPEND PROPERTY 
LINK_INTERFACE_LIBRARIES testLib3
 add_library(noIncludesInterface empty.cpp)
 
 install(TARGETS testLibRequired
-testLibIncludeRequired1
-testLibIncludeRequired2
-testLibIncludeRequired3
-testLibIncludeRequired4
-testLibIncludeRequired5
-testLibIncludeRequired6
-testSharedLibRequire

[Cmake-commits] CMake branch, next, updated. v2.8.11.2-3548-g14668d1

2013-07-31 Thread Daniele E . Domenichelli
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, next has been updated
   via  14668d1346619005d94b3c1777acb85abb0a4a57 (commit)
   via  7ca5958820b7741b251081af66e1cb67af243fd5 (commit)
   via  76c72b9f14258933e4cf810da275bd2b931c5ac9 (commit)
  from  c57b8d5618a6dd664b932b92c9c87ccc3dbcfed4 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=14668d1346619005d94b3c1777acb85abb0a4a57
commit 14668d1346619005d94b3c1777acb85abb0a4a57
Merge: c57b8d5 7ca5958
Author: Daniele E. Domenichelli 
AuthorDate: Wed Jul 31 11:42:35 2013 -0400
Commit: CMake Topic Stage 
CommitDate: Wed Jul 31 11:42:35 2013 -0400

Merge topic 'FindGTK2-gmodule' into next

7ca5958 FindGTK2: Detect gmodule library
76c72b9 FindGTK2: gthread-2.0 folder does not exist


http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=7ca5958820b7741b251081af66e1cb67af243fd5
commit 7ca5958820b7741b251081af66e1cb67af243fd5
Author: Daniele E. Domenichelli 
AuthorDate: Wed Jul 31 17:40:07 2013 +0200
Commit: Daniele E. Domenichelli 
CommitDate: Wed Jul 31 17:40:07 2013 +0200

FindGTK2: Detect gmodule library

diff --git a/Modules/FindGTK2.cmake b/Modules/FindGTK2.cmake
index efb1d9f..f7d3bf8 100644
--- a/Modules/FindGTK2.cmake
+++ b/Modules/FindGTK2.cmake
@@ -77,6 +77,7 @@
 # appropriate. A new set of _RELEASE variables was also added.
 #   * Remove GTK2_SKIP_MARK_AS_ADVANCED option, as now the variables are
 # marked as advanced by SelectLibraryConfigurations
+#   * Detect gmodule library
 # Version 1.4 (10/4/2012) (CMake 2.8.10)
 #   * 12596: Missing paths for FindGTK2 on NetBSD
 #   * 12049: Fixed detection of GTK include files in the lib folder on
@@ -482,6 +483,8 @@ foreach(_GTK2_component ${GTK2_FIND_COMPONENTS})
 
 _GTK2_FIND_LIBRARY(GTK2_GTHREAD gthread false true)
 
+_GTK2_FIND_LIBRARY(GTK2_GMODULE gmodule false true)
+
 _GTK2_FIND_LIBRARY(GTK2_GIO gio false true)
 
 _GTK2_FIND_INCLUDE_DIR(GTK2_ATK atk/atk.h)

http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=76c72b9f14258933e4cf810da275bd2b931c5ac9
commit 76c72b9f14258933e4cf810da275bd2b931c5ac9
Author: Daniele E. Domenichelli 
AuthorDate: Wed Jul 31 17:37:46 2013 +0200
Commit: Daniele E. Domenichelli 
CommitDate: Wed Jul 31 17:39:38 2013 +0200

FindGTK2: gthread-2.0 folder does not exist

Partially revert commit 508e8ca024e47baea342da85c7bbd014c7fd6c30

diff --git a/Modules/FindGTK2.cmake b/Modules/FindGTK2.cmake
index 4f522e5..efb1d9f 100644
--- a/Modules/FindGTK2.cmake
+++ b/Modules/FindGTK2.cmake
@@ -178,7 +178,6 @@ function(_GTK2_FIND_INCLUDE_DIR _var _hdr)
 cairo
 cairomm-1.0
 gdk-pixbuf-2.0
-gthread-2.0
 gdkmm-2.4
 giomm-2.4
 gtk-2.0

---

Summary of changes:
 Modules/FindGTK2.cmake |4 +++-
 1 files changed, 3 insertions(+), 1 deletions(-)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/cgi-bin/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, next, updated. v2.8.11.2-3545-gc57b8d5

2013-07-31 Thread Stephen Kelly
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, next has been updated
   via  c57b8d5618a6dd664b932b92c9c87ccc3dbcfed4 (commit)
   via  742994125417b30443e8e58a72a2839c31d97c23 (commit)
  from  8fcf9ac319a174bb427de84f1d9188e07bb773f4 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=c57b8d5618a6dd664b932b92c9c87ccc3dbcfed4
commit c57b8d5618a6dd664b932b92c9c87ccc3dbcfed4
Merge: 8fcf9ac 7429941
Author: Stephen Kelly 
AuthorDate: Wed Jul 31 11:15:08 2013 -0400
Commit: CMake Topic Stage 
CommitDate: Wed Jul 31 11:15:08 2013 -0400

Merge topic 'minor-cleanups' into next

7429941 Docs: Fix typo in CMAKE_DEBUG_TARGET_PROPERTIES


http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=742994125417b30443e8e58a72a2839c31d97c23
commit 742994125417b30443e8e58a72a2839c31d97c23
Author: Stephen Kelly 
AuthorDate: Wed Jul 31 17:13:46 2013 +0200
Commit: Stephen Kelly 
CommitDate: Wed Jul 31 17:13:46 2013 +0200

Docs: Fix typo in CMAKE_DEBUG_TARGET_PROPERTIES

Introduced in commit f10e6480 (Docs: Document existing target
property debugging options., 2013-07-26)

diff --git a/Source/cmDocumentVariables.cxx b/Source/cmDocumentVariables.cxx
index 91e278e..2c2d377 100644
--- a/Source/cmDocumentVariables.cxx
+++ b/Source/cmDocumentVariables.cxx
@@ -966,8 +966,7 @@ void cmDocumentVariables::DefineVariables(cmake* cm)
  "only be used when evaluating the INCLUDE_DIRECTORIES, "
  "COMPILE_DEFINITIONS and COMPILE_OPTIONS target properties.  "
  "In that case, it outputs a backtrace for each entry in the target "
- "propertythe build.  Default is unset.",
- false,"Variables That Change Behavior");
+ "property.  Default is unset.", false, "Variables That Change Behavior");
 
   // Variables defined by CMake that describe the system
 

---

Summary of changes:
 Source/cmDocumentVariables.cxx |3 +--
 1 files changed, 1 insertions(+), 2 deletions(-)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/cgi-bin/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, next, updated. v2.8.11.2-3543-g8fcf9ac

2013-07-31 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, next has been updated
   via  8fcf9ac319a174bb427de84f1d9188e07bb773f4 (commit)
   via  b64e8f22a4f08972e2d4b2bd5bd338247ec0946c (commit)
  from  29960ae9781614a8f171d5786fcb8e2b7a009004 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=8fcf9ac319a174bb427de84f1d9188e07bb773f4
commit 8fcf9ac319a174bb427de84f1d9188e07bb773f4
Merge: 29960ae b64e8f2
Author: Brad King 
AuthorDate: Wed Jul 31 10:22:10 2013 -0400
Commit: CMake Topic Stage 
CommitDate: Wed Jul 31 10:22:10 2013 -0400

Merge topic 'vs-subsystem-order' into next

b64e8f2 VS10: Honor user-specified /SUBSYSTEM: flag (#14326)


http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=b64e8f22a4f08972e2d4b2bd5bd338247ec0946c
commit b64e8f22a4f08972e2d4b2bd5bd338247ec0946c
Author: Brad King 
AuthorDate: Wed Jul 31 10:14:33 2013 -0400
Commit: Brad King 
CommitDate: Wed Jul 31 10:17:17 2013 -0400

VS10: Honor user-specified /SUBSYSTEM: flag (#14326)

Use the WIN32_EXECUTABLE target property only to set the SubSystem build
attribute default.  When user-specified flags are later parsed they may
then override it.

diff --git a/Source/cmVisualStudio10TargetGenerator.cxx 
b/Source/cmVisualStudio10TargetGenerator.cxx
index da5696a..1130704 100644
--- a/Source/cmVisualStudio10TargetGenerator.cxx
+++ b/Source/cmVisualStudio10TargetGenerator.cxx
@@ -1520,11 +1520,11 @@ 
cmVisualStudio10TargetGenerator::ComputeLinkOptions(std::string const& config)
 }
   if ( this->Target->GetPropertyAsBool("WIN32_EXECUTABLE") )
 {
-flags += " /SUBSYSTEM:WINDOWS";
+linkOptions.AddFlag("SubSystem", "Windows");
 }
   else
 {
-flags += " /SUBSYSTEM:CONSOLE";
+linkOptions.AddFlag("SubSystem", "Console");
 }
   std::string standardLibsVar = "CMAKE_";
   standardLibsVar += linkLanguage;

---

Summary of changes:
 Source/cmVisualStudio10TargetGenerator.cxx |4 ++--
 1 files changed, 2 insertions(+), 2 deletions(-)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/cgi-bin/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, next, updated. v2.8.11.2-3541-g29960ae

2013-07-31 Thread Stephen Kelly
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, next has been updated
   via  29960ae9781614a8f171d5786fcb8e2b7a009004 (commit)
   via  e79ab6ab396c70e6baf5bbb813d6d2773fb2f189 (commit)
  from  e23f1338b6bbd75cf2a93e9fa7fef7a86656ec7b (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=29960ae9781614a8f171d5786fcb8e2b7a009004
commit 29960ae9781614a8f171d5786fcb8e2b7a009004
Merge: e23f133 e79ab6a
Author: Stephen Kelly 
AuthorDate: Wed Jul 31 10:10:30 2013 -0400
Commit: CMake Topic Stage 
CommitDate: Wed Jul 31 10:10:30 2013 -0400

Merge topic 'fix-target-property-command-docs' into next

e79ab6a Revert "Docs: Document that target property commands require at 
least one item."


http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=e79ab6ab396c70e6baf5bbb813d6d2773fb2f189
commit e79ab6ab396c70e6baf5bbb813d6d2773fb2f189
Author: Stephen Kelly 
AuthorDate: Wed Jul 31 16:09:43 2013 +0200
Commit: Stephen Kelly 
CommitDate: Wed Jul 31 16:09:43 2013 +0200

Revert "Docs: Document that target property commands require at least one 
item."

This reverts commit 452e58525bb1656df0a169c8a047c25837caa4cf.

diff --git a/Source/cmTargetCompileDefinitionsCommand.h 
b/Source/cmTargetCompileDefinitionsCommand.h
index e593d9c..585485d 100644
--- a/Source/cmTargetCompileDefinitionsCommand.h
+++ b/Source/cmTargetCompileDefinitionsCommand.h
@@ -54,7 +54,7 @@ public:
 {
 return
   "  target_compile_definitions( "
-  " item [items1...]\n"
+  " [items1...]\n"
   "[ [items2...] ...])\n"
   "Specify compile definitions to use when compiling a given target.  "
   "The named  must have been created by a command such as "
diff --git a/Source/cmTargetCompileOptionsCommand.h 
b/Source/cmTargetCompileOptionsCommand.h
index 6185919..b9afd71 100644
--- a/Source/cmTargetCompileOptionsCommand.h
+++ b/Source/cmTargetCompileOptionsCommand.h
@@ -54,7 +54,7 @@ public:
 {
 return
   "  target_compile_options( [BEFORE] "
-  " item [items1...]\n"
+  " [items1...]\n"
   "[ [items2...] ...])\n"
   "Specify compile options to use when compiling a given target.  "
   "The named  must have been created by a command such as "
diff --git a/Source/cmTargetIncludeDirectoriesCommand.h 
b/Source/cmTargetIncludeDirectoriesCommand.h
index 69b5e03..fcc37f0 100644
--- a/Source/cmTargetIncludeDirectoriesCommand.h
+++ b/Source/cmTargetIncludeDirectoriesCommand.h
@@ -55,7 +55,7 @@ public:
 {
 return
   "  target_include_directories( [SYSTEM] [BEFORE] "
-  " item [items1...]\n"
+  " [items1...]\n"
   "[ [items2...] ...])\n"
   "Specify include directories or targets to use when compiling a given "
   "target.  "

---

Summary of changes:
 Source/cmTargetCompileDefinitionsCommand.h |2 +-
 Source/cmTargetCompileOptionsCommand.h |2 +-
 Source/cmTargetIncludeDirectoriesCommand.h |2 +-
 3 files changed, 3 insertions(+), 3 deletions(-)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/cgi-bin/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, next, updated. v2.8.11.2-3539-ge23f133

2013-07-31 Thread Stephen Kelly
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, next has been updated
   via  e23f1338b6bbd75cf2a93e9fa7fef7a86656ec7b (commit)
   via  c0b868220084ad6d2ca88a4fdd9564f887374fc2 (commit)
  from  0192404df3e4bb1ab4b2032043e91ca39a833007 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=e23f1338b6bbd75cf2a93e9fa7fef7a86656ec7b
commit e23f1338b6bbd75cf2a93e9fa7fef7a86656ec7b
Merge: 0192404 c0b8682
Author: Stephen Kelly 
AuthorDate: Wed Jul 31 10:08:56 2013 -0400
Commit: CMake Topic Stage 
CommitDate: Wed Jul 31 10:08:56 2013 -0400

Merge topic 'target-command-allow-no-items' into next

c0b8682 Allow target commands to be invoked with no items (#14325).


http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=c0b868220084ad6d2ca88a4fdd9564f887374fc2
commit c0b868220084ad6d2ca88a4fdd9564f887374fc2
Author: Stephen Kelly 
AuthorDate: Wed Jul 31 16:02:07 2013 +0200
Commit: Stephen Kelly 
CommitDate: Wed Jul 31 16:06:34 2013 +0200

Allow target commands to be invoked with no items (#14325).

Code such as

 target_include_directories(foo PRIVATE ${items})

should not work or break based on whether items is defined or not.

diff --git a/Source/cmTargetPropCommandBase.cxx 
b/Source/cmTargetPropCommandBase.cxx
index 287ce46..37aa604 100644
--- a/Source/cmTargetPropCommandBase.cxx
+++ b/Source/cmTargetPropCommandBase.cxx
@@ -19,7 +19,7 @@ bool cmTargetPropCommandBase
 ::HandleArguments(std::vector const& args, const char *prop,
  ArgumentFlags flags)
 {
-  if(args.size() < 3)
+  if(args.size() < 2)
 {
 this->SetError("called with incorrect number of arguments");
 return false;
@@ -53,7 +53,7 @@ bool cmTargetPropCommandBase
 
   if ((flags & PROCESS_SYSTEM) && args[argIndex] == "SYSTEM")
 {
-if (args.size() < 4)
+if (args.size() < 3)
   {
   this->SetError("called with incorrect number of arguments");
   return false;
@@ -65,7 +65,7 @@ bool cmTargetPropCommandBase
   bool prepend = false;
   if ((flags & PROCESS_BEFORE) && args[argIndex] == "BEFORE")
 {
-if (args.size() < 4)
+if (args.size() < 3)
   {
   this->SetError("called with incorrect number of arguments");
   return false;
diff --git a/Tests/CMakeCommands/target_compile_definitions/CMakeLists.txt 
b/Tests/CMakeCommands/target_compile_definitions/CMakeLists.txt
index 6d0e646..900dbd0 100644
--- a/Tests/CMakeCommands/target_compile_definitions/CMakeLists.txt
+++ b/Tests/CMakeCommands/target_compile_definitions/CMakeLists.txt
@@ -20,3 +20,8 @@ target_compile_definitions(consumer
   PRIVATE 
$
   -DDASH_D_DEFINE
 )
+
+# Test no items
+target_compile_definitions(consumer
+  PRIVATE
+)
diff --git a/Tests/CMakeCommands/target_compile_options/CMakeLists.txt 
b/Tests/CMakeCommands/target_compile_options/CMakeLists.txt
index 06a48fb..1d04639 100644
--- a/Tests/CMakeCommands/target_compile_options/CMakeLists.txt
+++ b/Tests/CMakeCommands/target_compile_options/CMakeLists.txt
@@ -33,3 +33,8 @@ if(CMAKE_CXX_COMPILER_ID MATCHES "GNU")
   "DO_GNU_TESTS"
   )
 endif()
+
+# Test no items
+target_compile_options(consumer
+  PRIVATE
+)
diff --git a/Tests/CMakeCommands/target_include_directories/CMakeLists.txt 
b/Tests/CMakeCommands/target_include_directories/CMakeLists.txt
index c03f0f8..21b8e15 100644
--- a/Tests/CMakeCommands/target_include_directories/CMakeLists.txt
+++ b/Tests/CMakeCommands/target_include_directories/CMakeLists.txt
@@ -47,3 +47,17 @@ target_include_directories(consumer
 $
   relative_dir
 )
+
+# Test no items
+target_include_directories(consumer
+  PRIVATE
+)
+target_include_directories(consumer
+  BEFORE PRIVATE
+)
+target_include_directories(consumer
+  SYSTEM BEFORE PRIVATE
+)
+target_include_directories(consumer
+  SYSTEM PRIVATE
+)

---

Summary of changes:
 Source/cmTargetPropCommandBase.cxx |6 +++---
 .../target_compile_definitions/CMakeLists.txt  |5 +
 .../target_compile_options/CMakeLists.txt  |5 +
 .../target_include_directories/CMakeLists.txt  |   14 ++
 4 files changed, 27 insertions(+), 3 deletions(-)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/cgi-bin/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, next, updated. v2.8.11.2-3537-g0192404

2013-07-31 Thread Stephen Kelly
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, next has been updated
   via  0192404df3e4bb1ab4b2032043e91ca39a833007 (commit)
   via  452e58525bb1656df0a169c8a047c25837caa4cf (commit)
  from  e07275e4938515491b4be5157cf16bb4f9b26aac (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=0192404df3e4bb1ab4b2032043e91ca39a833007
commit 0192404df3e4bb1ab4b2032043e91ca39a833007
Merge: e07275e 452e585
Author: Stephen Kelly 
AuthorDate: Wed Jul 31 09:11:14 2013 -0400
Commit: CMake Topic Stage 
CommitDate: Wed Jul 31 09:11:14 2013 -0400

Merge topic 'fix-target-property-command-docs' into next

452e585 Docs: Document that target property commands require at least one 
item.


http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=452e58525bb1656df0a169c8a047c25837caa4cf
commit 452e58525bb1656df0a169c8a047c25837caa4cf
Author: Stephen Kelly 
AuthorDate: Wed Jul 31 15:10:23 2013 +0200
Commit: Stephen Kelly 
CommitDate: Wed Jul 31 15:10:47 2013 +0200

Docs: Document that target property commands require at least one item.

diff --git a/Source/cmTargetCompileDefinitionsCommand.h 
b/Source/cmTargetCompileDefinitionsCommand.h
index 585485d..e593d9c 100644
--- a/Source/cmTargetCompileDefinitionsCommand.h
+++ b/Source/cmTargetCompileDefinitionsCommand.h
@@ -54,7 +54,7 @@ public:
 {
 return
   "  target_compile_definitions( "
-  " [items1...]\n"
+  " item [items1...]\n"
   "[ [items2...] ...])\n"
   "Specify compile definitions to use when compiling a given target.  "
   "The named  must have been created by a command such as "
diff --git a/Source/cmTargetCompileOptionsCommand.h 
b/Source/cmTargetCompileOptionsCommand.h
index b9afd71..6185919 100644
--- a/Source/cmTargetCompileOptionsCommand.h
+++ b/Source/cmTargetCompileOptionsCommand.h
@@ -54,7 +54,7 @@ public:
 {
 return
   "  target_compile_options( [BEFORE] "
-  " [items1...]\n"
+  " item [items1...]\n"
   "[ [items2...] ...])\n"
   "Specify compile options to use when compiling a given target.  "
   "The named  must have been created by a command such as "
diff --git a/Source/cmTargetIncludeDirectoriesCommand.h 
b/Source/cmTargetIncludeDirectoriesCommand.h
index fcc37f0..69b5e03 100644
--- a/Source/cmTargetIncludeDirectoriesCommand.h
+++ b/Source/cmTargetIncludeDirectoriesCommand.h
@@ -55,7 +55,7 @@ public:
 {
 return
   "  target_include_directories( [SYSTEM] [BEFORE] "
-  " [items1...]\n"
+  " item [items1...]\n"
   "[ [items2...] ...])\n"
   "Specify include directories or targets to use when compiling a given "
   "target.  "

---

Summary of changes:
 Source/cmTargetCompileDefinitionsCommand.h |2 +-
 Source/cmTargetCompileOptionsCommand.h |2 +-
 Source/cmTargetIncludeDirectoriesCommand.h |2 +-
 3 files changed, 3 insertions(+), 3 deletions(-)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/cgi-bin/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, next, updated. v2.8.11.2-3522-gf717142

2013-07-31 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, next has been updated
   via  f717142ce5db3ca731707606781266cb3878887a (commit)
   via  33e6e0b9c2ae26c8d077e577ded49debb75d1070 (commit)
   via  152dfdab11f66f4675c7f9af1cff6d301b1e271a (commit)
   via  20ed496b6d98bd2e28c2657c3383dd0cdbae9f4d (commit)
   via  54f7019fd06d2aaabeb24f6f5b0379e574cb9fb8 (commit)
   via  2a43c306fe434b87b087586c2e45d3e1fbe56d33 (commit)
   via  14bbf8340ac4d285b61afb5b61ebc4c730f4b4fa (commit)
  from  deeb80a6cb4ded8d5ce8fe2c493d208dda975d6b (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=f717142ce5db3ca731707606781266cb3878887a
commit f717142ce5db3ca731707606781266cb3878887a
Merge: deeb80a 33e6e0b
Author: Brad King 
AuthorDate: Wed Jul 31 08:42:04 2013 -0400
Commit: CMake Topic Stage 
CommitDate: Wed Jul 31 08:42:04 2013 -0400

Merge topic 'static_library_flags' into next

33e6e0b VS6: Add handling of CMAKE_*_LINKER_FLAGS_ variables
152dfda Add additonal tests for the linker flags
20ed496 Add documentation for the missing CMAKE_*_LINKER_FLAGS_* variables
54f7019 Add CMAKE_STATIC_LINKER_FLAGS to CMakeCommonLanguageInclude
2a43c30 Add support for CMAKE_STATIC_LINKER_FLAGS
14bbf83 Unify the way the flags of a static library are read


http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=33e6e0b9c2ae26c8d077e577ded49debb75d1070
commit 33e6e0b9c2ae26c8d077e577ded49debb75d1070
Author: Patrick Gansterer 
AuthorDate: Tue Jul 30 12:23:50 2013 +0200
Commit: Brad King 
CommitDate: Wed Jul 31 08:41:08 2013 -0400

VS6: Add handling of CMAKE_*_LINKER_FLAGS_ variables

Read the content of the config specific linker flags in the
Visual Studio 6 generator too.

diff --git a/Source/cmLocalVisualStudio6Generator.cxx 
b/Source/cmLocalVisualStudio6Generator.cxx
index 5ca8aba..667d86f 100644
--- a/Source/cmLocalVisualStudio6Generator.cxx
+++ b/Source/cmLocalVisualStudio6Generator.cxx
@@ -1171,18 +1171,42 @@ void cmLocalVisualStudio6Generator
   std::string extraLinkOptionsRelWithDebInfo;
   if(target.GetType() == cmTarget::EXECUTABLE)
 {
-extraLinkOptions =
-  this->Makefile->GetRequiredDefinition("CMAKE_EXE_LINKER_FLAGS");
+extraLinkOptions = this->Makefile->
+  GetRequiredDefinition("CMAKE_EXE_LINKER_FLAGS");
+extraLinkOptionsDebug = this->Makefile->
+  GetRequiredDefinition("CMAKE_EXE_LINKER_FLAGS_DEBUG");
+extraLinkOptionsRelease = this->Makefile->
+  GetRequiredDefinition("CMAKE_EXE_LINKER_FLAGS_RELEASE");
+extraLinkOptionsMinSizeRel = this->Makefile->
+  GetRequiredDefinition("CMAKE_EXE_LINKER_FLAGS_MINSIZEREL");
+extraLinkOptionsRelWithDebInfo = this->Makefile->
+  GetRequiredDefinition("CMAKE_EXE_LINKER_FLAGS_RELWITHDEBINFO");
 }
   if(target.GetType() == cmTarget::SHARED_LIBRARY)
 {
-extraLinkOptions =
-  this->Makefile->GetRequiredDefinition("CMAKE_SHARED_LINKER_FLAGS");
+extraLinkOptions = this->Makefile->
+  GetRequiredDefinition("CMAKE_SHARED_LINKER_FLAGS");
+extraLinkOptionsDebug = this->Makefile->
+  GetRequiredDefinition("CMAKE_SHARED_LINKER_FLAGS_DEBUG");
+extraLinkOptionsRelease = this->Makefile->
+  GetRequiredDefinition("CMAKE_SHARED_LINKER_FLAGS_RELEASE");
+extraLinkOptionsMinSizeRel = this->Makefile->
+  GetRequiredDefinition("CMAKE_SHARED_LINKER_FLAGS_MINSIZEREL");
+extraLinkOptionsRelWithDebInfo = this->Makefile->
+  GetRequiredDefinition("CMAKE_SHARED_LINKER_FLAGS_RELWITHDEBINFO");
 }
   if(target.GetType() == cmTarget::MODULE_LIBRARY)
 {
-extraLinkOptions =
-  this->Makefile->GetRequiredDefinition("CMAKE_MODULE_LINKER_FLAGS");
+extraLinkOptions = this->Makefile->
+  GetRequiredDefinition("CMAKE_MODULE_LINKER_FLAGS");
+extraLinkOptionsDebug = this->Makefile->
+  GetRequiredDefinition("CMAKE_MODULE_LINKER_FLAGS_DEBUG");
+extraLinkOptionsRelease = this->Makefile->
+  GetRequiredDefinition("CMAKE_MODULE_LINKER_FLAGS_RELEASE");
+extraLinkOptionsMinSizeRel = this->Makefile->
+  GetRequiredDefinition("CMAKE_MODULE_LINKER_FLAGS_MINSIZEREL");
+extraLinkOptionsRelWithDebInfo = this->Makefile->
+  GetRequiredDefinition("CMAKE_MODULE_LINKER_FLAGS_RELWITHDEBINFO");
 }
 
   // Get extra linker options for this target.

http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=152dfdab11f66f4675c7f9af1cff6d301b1e271a
commit 152dfdab11f66f4675c7f9af1cff6d301b1e271a
Author: Patrick Gansterer 
AuthorDate: Sun Jul 28 20:34:16 2013 +0200
Commit: Brad King 
CommitDate: Wed Jul 31 08:41:08 2013 -0400

Add additonal tes

[Cmake-commits] CMake branch, next, updated. v2.8.11.2-3506-gb11ce2c

2013-07-31 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, next has been updated
   via  b11ce2cc030b4a59a9a4dfc75d91fb21ac068367 (commit)
   via  4056e88c13cd092fd08cccf805712d2773025186 (commit)
  from  97bd7a8ba4a45727aab5f1046189ec1182128515 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=b11ce2cc030b4a59a9a4dfc75d91fb21ac068367
commit b11ce2cc030b4a59a9a4dfc75d91fb21ac068367
Merge: 97bd7a8 4056e88
Author: Brad King 
AuthorDate: Wed Jul 31 08:26:22 2013 -0400
Commit: CMake Topic Stage 
CommitDate: Wed Jul 31 08:26:22 2013 -0400

Merge topic 'update-libarchive' into next

4056e88 libarchive: Update README for new upstream snapshot commit hash


http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=4056e88c13cd092fd08cccf805712d2773025186
commit 4056e88c13cd092fd08cccf805712d2773025186
Author: Brad King 
AuthorDate: Wed Jul 31 08:23:44 2013 -0400
Commit: Brad King 
CommitDate: Wed Jul 31 08:23:44 2013 -0400

libarchive: Update README for new upstream snapshot commit hash

diff --git a/Utilities/cmlibarchive/README-CMake.txt 
b/Utilities/cmlibarchive/README-CMake.txt
index d43bbd6..ab105f0 100644
--- a/Utilities/cmlibarchive/README-CMake.txt
+++ b/Utilities/cmlibarchive/README-CMake.txt
@@ -11,7 +11,7 @@ branch, but it is merged into our history.
 Update libarchive from upstream as follows.  Create a local branch to
 explicitly reference the upstream snapshot branch head:
 
- git branch libarchive-upstream 0ce42049
+ git branch libarchive-upstream 35df7c8b
 
 Use a temporary directory to checkout the branch:
 
@@ -24,7 +24,7 @@ Use a temporary directory to checkout the branch:
 Now place the (reduced) libarchive content in this directory.  See
 instructions shown by
 
- git log 0ce42049
+ git log 35df7c8b
 
 for help extracting the content from the upstream svn repo.  Then run
 the following commands to commit the new version.  Substitute the

---

Summary of changes:
 Utilities/cmlibarchive/README-CMake.txt |4 ++--
 1 files changed, 2 insertions(+), 2 deletions(-)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/cgi-bin/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, next, updated. v2.8.11.2-3504-g97bd7a8

2013-07-31 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, next has been updated
   via  97bd7a8ba4a45727aab5f1046189ec1182128515 (commit)
   via  fbed829beaad4b9757662497c1a91391c4066015 (commit)
  from  9af30f931888bfc140dec76149ced5eb36d6b0da (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=97bd7a8ba4a45727aab5f1046189ec1182128515
commit 97bd7a8ba4a45727aab5f1046189ec1182128515
Merge: 9af30f9 fbed829
Author: Brad King 
AuthorDate: Wed Jul 31 08:02:00 2013 -0400
Commit: CMake Topic Stage 
CommitDate: Wed Jul 31 08:02:00 2013 -0400

Merge topic 'update-libarchive' into next

fbed829 libarchive: Convert CRLF -> LF newlines


http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=fbed829beaad4b9757662497c1a91391c4066015
commit fbed829beaad4b9757662497c1a91391c4066015
Author: Brad King 
AuthorDate: Wed Jul 31 07:57:42 2013 -0400
Commit: Brad King 
CommitDate: Wed Jul 31 07:57:42 2013 -0400

libarchive: Convert CRLF -> LF newlines

diff --git a/Utilities/cmlibarchive/build/cmake/FindLibGCC.cmake 
b/Utilities/cmlibarchive/build/cmake/FindLibGCC.cmake
index 5883ff8..7985f2b 100644
--- a/Utilities/cmlibarchive/build/cmake/FindLibGCC.cmake
+++ b/Utilities/cmlibarchive/build/cmake/FindLibGCC.cmake
@@ -1,22 +1,22 @@
-# - Find libgcc
-# Find the libgcc library.
-#
-#  LIBGCC_LIBRARIES  - List of libraries when using libgcc
-#  LIBGCC_FOUND  - True if libgcc found.
-
-IF (LIBGCC_LIBRARY)
-  # Already in cache, be silent
-  SET(LIBGCC_FIND_QUIETLY TRUE)
-ENDIF (LIBGCC_LIBRARY)
-
-FIND_LIBRARY(LIBGCC_LIBRARY NAMES gcc libgcc)
-
-# handle the QUIETLY and REQUIRED arguments and set LIBGCC_FOUND to TRUE if 
-# all listed variables are TRUE
-INCLUDE(FindPackageHandleStandardArgs)
-FIND_PACKAGE_HANDLE_STANDARD_ARGS(LIBGCC DEFAULT_MSG LIBGCC_LIBRARY)
-
-IF(LIBGCC_FOUND)
-  SET(LIBGCC_LIBRARIES ${LIBGCC_LIBRARY})
-  SET(HAVE_LIBGCC 1)
-ENDIF(LIBGCC_FOUND)
+# - Find libgcc
+# Find the libgcc library.
+#
+#  LIBGCC_LIBRARIES  - List of libraries when using libgcc
+#  LIBGCC_FOUND  - True if libgcc found.
+
+IF (LIBGCC_LIBRARY)
+  # Already in cache, be silent
+  SET(LIBGCC_FIND_QUIETLY TRUE)
+ENDIF (LIBGCC_LIBRARY)
+
+FIND_LIBRARY(LIBGCC_LIBRARY NAMES gcc libgcc)
+
+# handle the QUIETLY and REQUIRED arguments and set LIBGCC_FOUND to TRUE if 
+# all listed variables are TRUE
+INCLUDE(FindPackageHandleStandardArgs)
+FIND_PACKAGE_HANDLE_STANDARD_ARGS(LIBGCC DEFAULT_MSG LIBGCC_LIBRARY)
+
+IF(LIBGCC_FOUND)
+  SET(LIBGCC_LIBRARIES ${LIBGCC_LIBRARY})
+  SET(HAVE_LIBGCC 1)
+ENDIF(LIBGCC_FOUND)
diff --git a/Utilities/cmlibarchive/build/cmake/FindNettle.cmake 
b/Utilities/cmlibarchive/build/cmake/FindNettle.cmake
index 54ec9f5..1f66610 100644
--- a/Utilities/cmlibarchive/build/cmake/FindNettle.cmake
+++ b/Utilities/cmlibarchive/build/cmake/FindNettle.cmake
@@ -1,23 +1,23 @@
-# - Find Nettle
-# Find the Nettle include directory and library
-#
-#  NETTLE_INCLUDE_DIR- where to find , etc.
-#  NETTLE_LIBRARIES  - List of libraries when using libnettle.
-#  NETTLE_FOUND  - True if libnettle found.
-
-IF (NETTLE_INCLUDE_DIR)
-  # Already in cache, be silent
-  SET(NETTLE_FIND_QUIETLY TRUE)
-ENDIF (NETTLE_INCLUDE_DIR)
-
-FIND_PATH(NETTLE_INCLUDE_DIR nettle/md5.h nettle/ripemd160.h nettle/sha.h)
-FIND_LIBRARY(NETTLE_LIBRARY NAMES nettle libnettle)
-
-# handle the QUIETLY and REQUIRED arguments and set NETTLE_FOUND to TRUE if 
-# all listed variables are TRUE
-INCLUDE(FindPackageHandleStandardArgs)
-FIND_PACKAGE_HANDLE_STANDARD_ARGS(NETTLE DEFAULT_MSG NETTLE_LIBRARY 
NETTLE_INCLUDE_DIR)
-
-IF(NETTLE_FOUND)
-  SET(NETTLE_LIBRARIES ${NETTLE_LIBRARY})
-ENDIF(NETTLE_FOUND)
+# - Find Nettle
+# Find the Nettle include directory and library
+#
+#  NETTLE_INCLUDE_DIR- where to find , etc.
+#  NETTLE_LIBRARIES  - List of libraries when using libnettle.
+#  NETTLE_FOUND  - True if libnettle found.
+
+IF (NETTLE_INCLUDE_DIR)
+  # Already in cache, be silent
+  SET(NETTLE_FIND_QUIETLY TRUE)
+ENDIF (NETTLE_INCLUDE_DIR)
+
+FIND_PATH(NETTLE_INCLUDE_DIR nettle/md5.h nettle/ripemd160.h nettle/sha.h)
+FIND_LIBRARY(NETTLE_LIBRARY NAMES nettle libnettle)
+
+# handle the QUIETLY and REQUIRED arguments and set NETTLE_FOUND to TRUE if 
+# all listed variables are TRUE
+INCLUDE(FindPackageHandleStandardArgs)
+FIND_PACKAGE_HANDLE_STANDARD_ARGS(NETTLE DEFAULT_MSG NETTLE_LIBRARY 
NETTLE_INCLUDE_DIR)
+
+IF(NETTLE_FOUND)
+  SET(NETTLE_LIBRARIES ${NETTLE_LIBRARY})
+ENDIF(NETTLE_FOUND)
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/cgi-bin/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, next, updated. v2.8.11.2-3535-ge07275e

2013-07-31 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, next has been updated
   via  e07275e4938515491b4be5157cf16bb4f9b26aac (commit)
   via  0cecc7b485774be084a6d5a72e743ed9893daa5d (commit)
   via  e3b6ab92dbb51945b81896f2d2a53f31ba63ae1a (commit)
   via  58c5dc37d307c1d2a85c42e84e71cb619a6956b0 (commit)
   via  4e3675ae916e824997c01989366408ff2107a96f (commit)
   via  f2db78c120ada2a084d69abe0296709f56c5ed10 (commit)
   via  b728ec3c3160e26dbfb7631aebd6fa22cfe6e20f (commit)
   via  cdfeda60f605fc8ef044ae28d4209a445ca09ffd (commit)
   via  6e2da4a4d3a34f62ec830720ab47d344ada73441 (commit)
   via  8e475470bec1761b9ab338f495e33b145e0ff22e (commit)
   via  9181a4e3b68ab28d8b26384f9f4983159b5dcf9b (commit)
  from  1237c224c6aa96ab5d3773b34431e60eb01f8fef (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=e07275e4938515491b4be5157cf16bb4f9b26aac
commit e07275e4938515491b4be5157cf16bb4f9b26aac
Merge: 1237c22 0cecc7b
Author: Brad King 
AuthorDate: Wed Jul 31 08:50:56 2013 -0400
Commit: Brad King 
CommitDate: Wed Jul 31 08:50:56 2013 -0400

Merge branch 'master' into next


---

Summary of changes:
 Source/CMakeVersion.cmake |2 +-
 1 files changed, 1 insertions(+), 1 deletions(-)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/cgi-bin/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, master, updated. v2.8.11.2-667-g0cecc7b

2013-07-31 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, master has been updated
   via  0cecc7b485774be084a6d5a72e743ed9893daa5d (commit)
   via  26fe7e3adfc76a733ecc74794f22d53755ac194a (commit)
   via  b81a4e1568c58d733051d9f27cd070761f264a80 (commit)
   via  3218f52f11713d28bdfedbe6eceddb8cf8502731 (commit)
   via  bae3a73ceea6163eeb6eae59dfcf838a43048831 (commit)
   via  677384017a343f1ca70342951a39302a683843a2 (commit)
   via  8dc0a9f898710215bd29fa260f790a7051dbaab2 (commit)
   via  102071f80cf4ad7aa97bf8a1618cfc6ee6689ab6 (commit)
   via  35df7c8ba8854e97bd6994c4d1143f57535ed6f2 (commit)
  from  e3b6ab92dbb51945b81896f2d2a53f31ba63ae1a (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=0cecc7b485774be084a6d5a72e743ed9893daa5d
commit 0cecc7b485774be084a6d5a72e743ed9893daa5d
Merge: e3b6ab9 26fe7e3
Author: Brad King 
AuthorDate: Wed Jul 31 08:49:09 2013 -0400
Commit: CMake Topic Stage 
CommitDate: Wed Jul 31 08:49:09 2013 -0400

Merge topic 'update-libarchive'

26fe7e3 libarchive: Backport to CMake 2.8.2
b81a4e1 libarchive: Remove build options not used by CMake
3218f52 libarchive: Avoid struct init with variable
bae3a73 libarchive: Silence API deprecation warnings
6773840 libarchive: Include cm_zlib.h to get zlib used by CMake
8dc0a9f libarchive: Update README-CMake.txt for new snapshot
102071f Merge branch 'libarchive-upstream' into update-libarchive
35df7c8 libarchive 3.1.2 (reduced)


---

Summary of changes:
 Utilities/cmlibarchive/CMakeLists.txt  |  326 +++-
 Utilities/cmlibarchive/README-CMake.txt|8 +-
 .../cmlibarchive/build/cmake/FindLibGCC.cmake  |   22 +
 .../cmlibarchive/build/cmake/FindNettle.cmake  |   23 +
 .../cmlibarchive/build/cmake/FindPCREPOSIX.cmake   |   34 +
 Utilities/cmlibarchive/build/cmake/config.h.in |   51 +-
 .../utils/gen_archive_string_composition_h.sh  |   47 +-
 Utilities/cmlibarchive/build/version   |2 +-
 Utilities/cmlibarchive/libarchive/CMakeLists.txt   |   23 +-
 Utilities/cmlibarchive/libarchive/archive.h|  308 +++-
 Utilities/cmlibarchive/libarchive/archive_acl.c|   82 +-
 .../cmlibarchive/libarchive/archive_check_magic.c  |1 +
 .../cmlibarchive/libarchive/archive_cmdline.c  |  227 +++
 .../libarchive/archive_cmdline_private.h   |   47 +
 Utilities/cmlibarchive/libarchive/archive_crypto.c |8 +-
 Utilities/cmlibarchive/libarchive/archive_endian.h |8 +-
 Utilities/cmlibarchive/libarchive/archive_entry.3  |6 +-
 Utilities/cmlibarchive/libarchive/archive_entry.c  |   81 +-
 Utilities/cmlibarchive/libarchive/archive_entry.h  |   45 +-
 .../cmlibarchive/libarchive/archive_entry_acl.3|6 +-
 .../libarchive/archive_entry_copy_bhfi.c   |6 +-
 .../libarchive/archive_entry_link_resolver.c   |5 +-
 .../libarchive/archive_entry_linkify.3 |4 +-
 .../cmlibarchive/libarchive/archive_entry_paths.3  |4 +-
 .../cmlibarchive/libarchive/archive_entry_perms.3  |4 +-
 .../cmlibarchive/libarchive/archive_entry_stat.3   |6 +-
 .../cmlibarchive/libarchive/archive_entry_stat.c   |   10 +-
 .../cmlibarchive/libarchive/archive_entry_time.3   |6 +-
 .../cmlibarchive/libarchive/archive_getdate.c  | 1037 +++
 Utilities/cmlibarchive/libarchive/archive_match.c  | 1841 
 .../cmlibarchive/libarchive/archive_options.c  |   53 +-
 .../cmlibarchive/libarchive/archive_pathmatch.c|  459 +
 .../cmlibarchive/libarchive/archive_pathmatch.h|   52 +
 Utilities/cmlibarchive/libarchive/archive_ppmd7.c  |7 +-
 .../cmlibarchive/libarchive/archive_ppmd_private.h |4 +-
 .../cmlibarchive/libarchive/archive_private.h  |2 +
 Utilities/cmlibarchive/libarchive/archive_rb.c |   24 +-
 Utilities/cmlibarchive/libarchive/archive_read.3   |6 +-
 Utilities/cmlibarchive/libarchive/archive_read.c   |  422 -
 .../libarchive/archive_read_append_filter.c|  198 +++
 .../cmlibarchive/libarchive/archive_read_data.3|4 +-
 .../libarchive/archive_read_data_into_fd.c |2 +-
 .../cmlibarchive/libarchive/archive_read_disk.3|6 +-
 .../libarchive/archive_read_disk_entry_from_file.c |  476 --
 .../libarchive/archive_read_disk_posix.c   |  580 +--
 .../libarchive/archive_read_disk_private.h |   23 +-
 .../libarchive/archive_read_disk_windows.c |  719 ++---
 .../cmlibarchive/libarchive/archive_read_extract.3 |4 +-
 .../cmlibarchive

[Cmake-commits] CMake branch, master, updated. v2.8.11.2-658-ge3b6ab9

2013-07-31 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, master has been updated
   via  e3b6ab92dbb51945b81896f2d2a53f31ba63ae1a (commit)
   via  33e6e0b9c2ae26c8d077e577ded49debb75d1070 (commit)
   via  152dfdab11f66f4675c7f9af1cff6d301b1e271a (commit)
   via  20ed496b6d98bd2e28c2657c3383dd0cdbae9f4d (commit)
   via  54f7019fd06d2aaabeb24f6f5b0379e574cb9fb8 (commit)
   via  2a43c306fe434b87b087586c2e45d3e1fbe56d33 (commit)
   via  14bbf8340ac4d285b61afb5b61ebc4c730f4b4fa (commit)
  from  58c5dc37d307c1d2a85c42e84e71cb619a6956b0 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=e3b6ab92dbb51945b81896f2d2a53f31ba63ae1a
commit e3b6ab92dbb51945b81896f2d2a53f31ba63ae1a
Merge: 58c5dc3 33e6e0b
Author: Brad King 
AuthorDate: Wed Jul 31 08:49:01 2013 -0400
Commit: CMake Topic Stage 
CommitDate: Wed Jul 31 08:49:01 2013 -0400

Merge topic 'static_library_flags'

33e6e0b VS6: Add handling of CMAKE_*_LINKER_FLAGS_ variables
152dfda Add additonal tests for the linker flags
20ed496 Add documentation for the missing CMAKE_*_LINKER_FLAGS_* variables
54f7019 Add CMAKE_STATIC_LINKER_FLAGS to CMakeCommonLanguageInclude
2a43c30 Add support for CMAKE_STATIC_LINKER_FLAGS
14bbf83 Unify the way the flags of a static library are read


---

Summary of changes:
 Modules/CMakeCommonLanguageInclude.cmake |   22 +
 Source/cmDocumentVariables.cxx   |   43 +
 Source/cmGlobalXCodeGenerator.cxx|   34 ---
 Source/cmLocalGenerator.cxx  |   40 
 Source/cmLocalGenerator.h|5 +
 Source/cmLocalVisualStudio6Generator.cxx |  101 ++
 Source/cmLocalVisualStudio7Generator.cxx |   12 +---
 Source/cmMakefileLibraryTargetGenerator.cxx  |8 +--
 Source/cmVisualStudio10TargetGenerator.cxx   |   13 +--
 Tests/CMakeLists.txt |   14 +++-
 Tests/LinkFlags/CMakeLists.txt   |9 ++
 Tests/LinkFlags/LinkerFlags/CMakeLists.txt   |   11 +++
 Tests/LinkFlags/LinkerFlagsConfig/CMakeLists.txt |   11 +++
 13 files changed, 223 insertions(+), 100 deletions(-)
 create mode 100644 Tests/LinkFlags/LinkerFlags/CMakeLists.txt
 create mode 100644 Tests/LinkFlags/LinkerFlagsConfig/CMakeLists.txt


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/cgi-bin/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, master, updated. v2.8.11.2-651-g58c5dc3

2013-07-31 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, master has been updated
   via  58c5dc37d307c1d2a85c42e84e71cb619a6956b0 (commit)
   via  8fbf39a471593e3607e67a8915a1ec0e150d3298 (commit)
  from  4e3675ae916e824997c01989366408ff2107a96f (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=58c5dc37d307c1d2a85c42e84e71cb619a6956b0
commit 58c5dc37d307c1d2a85c42e84e71cb619a6956b0
Merge: 4e3675a 8fbf39a
Author: Brad King 
AuthorDate: Wed Jul 31 08:48:57 2013 -0400
Commit: CMake Topic Stage 
CommitDate: Wed Jul 31 08:48:57 2013 -0400

Merge topic '13582_configured_file_regeneration'

8fbf39a cmMakefile: Do not track configured files known to be temporary


---

Summary of changes:
 Source/cmMakefile.cxx |6 +-
 1 files changed, 5 insertions(+), 1 deletions(-)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/cgi-bin/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, master, updated. v2.8.11.2-647-gf2db78c

2013-07-31 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, master has been updated
   via  f2db78c120ada2a084d69abe0296709f56c5ed10 (commit)
   via  f85f6a5e795e7c552944a885a1f5f978fa847433 (commit)
   via  351fd63ef5d8f24955b3e061fd43c1c9f1aa570d (commit)
  from  b728ec3c3160e26dbfb7631aebd6fa22cfe6e20f (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=f2db78c120ada2a084d69abe0296709f56c5ed10
commit f2db78c120ada2a084d69abe0296709f56c5ed10
Merge: b728ec3 f85f6a5
Author: Brad King 
AuthorDate: Wed Jul 31 08:48:40 2013 -0400
Commit: CMake Topic Stage 
CommitDate: Wed Jul 31 08:48:40 2013 -0400

Merge topic 'bash-completion-updates'

f85f6a5 bash-completion: Fix/improve generator names extraction
351fd63 bash-completion: Add -S,-SP options arguments completion


---

Summary of changes:
 Docs/bash-completion/cmake |8 +---
 Docs/bash-completion/cpack |4 ++--
 Docs/bash-completion/ctest |2 +-
 3 files changed, 8 insertions(+), 6 deletions(-)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/cgi-bin/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, master, updated. v2.8.11.2-644-gb728ec3

2013-07-31 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, master has been updated
   via  b728ec3c3160e26dbfb7631aebd6fa22cfe6e20f (commit)
   via  72d13ff4826ff3e120fe2d052495b0806c2a5b90 (commit)
  from  cdfeda60f605fc8ef044ae28d4209a445ca09ffd (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=b728ec3c3160e26dbfb7631aebd6fa22cfe6e20f
commit b728ec3c3160e26dbfb7631aebd6fa22cfe6e20f
Merge: cdfeda6 72d13ff
Author: Brad King 
AuthorDate: Wed Jul 31 08:48:36 2013 -0400
Commit: CMake Topic Stage 
CommitDate: Wed Jul 31 08:48:36 2013 -0400

Merge topic 'install-interface-includes'

72d13ff install: Remove error condition using INCLUDES DESTINATION without 
EXPORT.


---

Summary of changes:
 Source/cmInstallCommand.cxx|7 ---
 .../include_directories/RunCMakeTest.cmake |1 -
 .../TargetInterfaceIncludes-result.txt |1 -
 .../TargetInterfaceIncludes-stderr.txt |4 
 .../TargetInterfaceIncludes.cmake  |4 
 5 files changed, 0 insertions(+), 17 deletions(-)
 delete mode 100644 
Tests/RunCMake/include_directories/TargetInterfaceIncludes-result.txt
 delete mode 100644 
Tests/RunCMake/include_directories/TargetInterfaceIncludes-stderr.txt
 delete mode 100644 
Tests/RunCMake/include_directories/TargetInterfaceIncludes.cmake


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/cgi-bin/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, master, updated. v2.8.11.2-640-g6e2da4a

2013-07-31 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, master has been updated
   via  6e2da4a4d3a34f62ec830720ab47d344ada73441 (commit)
   via  2b473d2eaa2d09a69fc5a4f37d24ad051d5ead9a (commit)
  from  8e475470bec1761b9ab338f495e33b145e0ff22e (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=6e2da4a4d3a34f62ec830720ab47d344ada73441
commit 6e2da4a4d3a34f62ec830720ab47d344ada73441
Merge: 8e47547 2b473d2
Author: Brad King 
AuthorDate: Wed Jul 31 08:48:19 2013 -0400
Commit: CMake Topic Stage 
CommitDate: Wed Jul 31 08:48:19 2013 -0400

Merge topic 'passthru'

2b473d2 Add option to use stdout/stderr of original terminal in cmake 
--build


---

Summary of changes:
 Source/cmSystemTools.cxx |8 +++-
 Source/cmSystemTools.h   |5 +++--
 Source/cmakemain.cxx |7 +--
 3 files changed, 15 insertions(+), 5 deletions(-)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/cgi-bin/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, master, updated. v2.8.11.2-649-g4e3675a

2013-07-31 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, master has been updated
   via  4e3675ae916e824997c01989366408ff2107a96f (commit)
   via  d12459f79ec5270cce7d425839674a71e83617ba (commit)
  from  f2db78c120ada2a084d69abe0296709f56c5ed10 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=4e3675ae916e824997c01989366408ff2107a96f
commit 4e3675ae916e824997c01989366408ff2107a96f
Merge: f2db78c d12459f
Author: Brad King 
AuthorDate: Wed Jul 31 08:48:52 2013 -0400
Commit: CMake Topic Stage 
CommitDate: Wed Jul 31 08:48:52 2013 -0400

Merge topic 'ninja_bad_cmcldeps_paths'

d12459f VS 6: Tell BuildDepends test to tolerate ninjadep failure


---

Summary of changes:
 Tests/BuildDepends/CMakeLists.txt |3 +++
 1 files changed, 3 insertions(+), 0 deletions(-)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/cgi-bin/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, master, updated. v2.8.11.2-642-gcdfeda6

2013-07-31 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, master has been updated
   via  cdfeda60f605fc8ef044ae28d4209a445ca09ffd (commit)
   via  9349d69abf69795e115329475d56ff0583b6c79c (commit)
  from  6e2da4a4d3a34f62ec830720ab47d344ada73441 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=cdfeda60f605fc8ef044ae28d4209a445ca09ffd
commit cdfeda60f605fc8ef044ae28d4209a445ca09ffd
Merge: 6e2da4a 9349d69
Author: Brad King 
AuthorDate: Wed Jul 31 08:48:29 2013 -0400
Commit: CMake Topic Stage 
CommitDate: Wed Jul 31 08:48:29 2013 -0400

Merge topic 'add-cmake_reset_check_state'

9349d69 Add cmake_reset_check_state() macro


---

Summary of changes:
 Modules/CMakePushCheckState.cmake |   33 -
 1 files changed, 28 insertions(+), 5 deletions(-)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/cgi-bin/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, next, updated. v2.8.11.2-3524-g1237c22

2013-07-31 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, next has been updated
   via  1237c224c6aa96ab5d3773b34431e60eb01f8fef (commit)
   via  9349d69abf69795e115329475d56ff0583b6c79c (commit)
  from  f717142ce5db3ca731707606781266cb3878887a (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=1237c224c6aa96ab5d3773b34431e60eb01f8fef
commit 1237c224c6aa96ab5d3773b34431e60eb01f8fef
Merge: f717142 9349d69
Author: Brad King 
AuthorDate: Wed Jul 31 08:45:26 2013 -0400
Commit: CMake Topic Stage 
CommitDate: Wed Jul 31 08:45:26 2013 -0400

Merge topic 'add-cmake_reset_check_state' into next

9349d69 Add cmake_reset_check_state() macro


http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=9349d69abf69795e115329475d56ff0583b6c79c
commit 9349d69abf69795e115329475d56ff0583b6c79c
Author: Vadim Zhukov 
AuthorDate: Sun Jul 28 14:11:51 2013 +0400
Commit: Brad King 
CommitDate: Wed Jul 31 08:43:22 2013 -0400

Add cmake_reset_check_state() macro

It's acknowledged that check state should not generally nest,
so it should be cleared when used, for example, in Find* module.

Also, add optional RESET argument to cmake_push_check_state().

diff --git a/Modules/CMakePushCheckState.cmake 
b/Modules/CMakePushCheckState.cmake
index 08809bf..b37b706 100644
--- a/Modules/CMakePushCheckState.cmake
+++ b/Modules/CMakePushCheckState.cmake
@@ -1,8 +1,10 @@
-# This module defines two macros:
+# This module defines three macros:
 # CMAKE_PUSH_CHECK_STATE()
-# and
 # CMAKE_POP_CHECK_STATE()
 # These two macros can be used to save and restore the state of the variables
 # CMAKE_REQUIRED_FLAGS, CMAKE_REQUIRED_DEFINITIONS, CMAKE_REQUIRED_LIBRARIES
 # and CMAKE_REQUIRED_INCLUDES used by the various Check-files coming with 
CMake,
 # like e.g. check_function_exists() etc.
@@ -11,9 +13,16 @@
 # but after the Find-module has been executed they should have the same value
 # as they had before.
 #
+# CMAKE_PUSH_CHECK_STATE() macro receives optional argument RESET. Whether 
it's specified,
+# CMAKE_PUSH_CHECK_STATE() will set all CMAKE_REQUIRED_* variables to empty 
values, same
+# as CMAKE_RESET_CHECK_STATE() call will do.
+#
 # Usage:
-#   cmake_push_check_state()
-#   set(CMAKE_REQUIRED_DEFINITIONS ${CMAKE_REQUIRED_DEFINITIONS} 
-DSOME_MORE_DEF)
+#   cmake_push_check_state(RESET)
+#   set(CMAKE_REQUIRED_DEFINITIONS -DSOME_MORE_DEF)
+#   check_function_exists(...)
+#   cmake_reset_check_state()
+#   set(CMAKE_REQUIRED_DEFINITIONS -DANOTHER_DEF)
 #   check_function_exists(...)
 #   cmake_pop_check_state()
 
@@ -31,6 +40,15 @@
 #  License text for the above reference.)
 
 
+macro(CMAKE_RESET_CHECK_STATE)
+
+   set(CMAKE_REQUIRED_INCLUDES)
+   set(CMAKE_REQUIRED_DEFINITIONS)
+   set(CMAKE_REQUIRED_LIBRARIES)
+   set(CMAKE_REQUIRED_FLAGS)
+
+endmacro()
+
 macro(CMAKE_PUSH_CHECK_STATE)
 
if(NOT DEFINED _CMAKE_PUSH_CHECK_STATE_COUNTER)
@@ -43,6 +61,11 @@ macro(CMAKE_PUSH_CHECK_STATE)
set(_CMAKE_REQUIRED_DEFINITIONS_SAVE_${_CMAKE_PUSH_CHECK_STATE_COUNTER} 
${CMAKE_REQUIRED_DEFINITIONS})
set(_CMAKE_REQUIRED_LIBRARIES_SAVE_${_CMAKE_PUSH_CHECK_STATE_COUNTER}   
${CMAKE_REQUIRED_LIBRARIES})
set(_CMAKE_REQUIRED_FLAGS_SAVE_${_CMAKE_PUSH_CHECK_STATE_COUNTER}   
${CMAKE_REQUIRED_FLAGS})
+
+   if (ARGC GREATER 0 AND ARGV0 STREQUAL "RESET")
+  cmake_reset_check_state()
+   endif()
+
 endmacro()
 
 macro(CMAKE_POP_CHECK_STATE)

---
@@ -1,8 +1,10 @@
 # CMAKE_POP_CHECK_STATE()
-# These two macros can be used to save and restore the state of the variables
+# and
+# CMAKE_RESET_CHECK_STATE()
+# These macros can be used to save, restore and reset (i.e., clear contents)
+# the state of the variables
 # CMAKE_REQUIRED_FLAGS, CMAKE_REQUIRED_DEFINITIONS, CMAKE_REQUIRED_LIBRARIES
 # and CMAKE_REQUIRED_INCLUDES used by the various Check-files coming with 

Summary of changes:


hooks/post-receive
diff --git a/Utilities/cmlibarchive/build/cmake/FindPCREPOSIX.cmake 
b/Utilities/cmlibarchive/build/cmake/FindPCREPOSIX.cmake
index 56cc17e..7cc40